@@ -8,29 +8,29 @@ extends 'API::Name::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
+
+has user => (
+    is       => 'rw',
+    isa      => Str,
+    required => 1,
+);
+
+has token => (
+    is       => 'rw',
+    isa      => Str,
+    required => 1,
+);
 
 has identifier => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     default  => 'API::Name (Perl)',
 );
 
-has apiuser => (
-    is       => 'rw',
-    isa      => STRING,
-    required => 1,
-);
-
-has apitoken => (
-    is       => 'rw',
-    isa      => STRING,
-    required => 1,
-);
-
 has version => (
     is       => 'rw',
-    isa      => INTEGER,
+    isa      => Int,
     default  => 1,
 );
 
@@ -61,13 +61,13 @@ method PREPARE ($ua, $tx, %args) {
     my $headers = $tx->req->headers;
     my $url     = $tx->req->url;
 
-    my $apiuser  = $self->apiuser;
-    my $apitoken = $self->apitoken;
+    my $user  = $self->user;
+    my $token = $self->token;
 
     # default headers
     $headers->header('Content-Type' => 'application/json');
-    $headers->header('Api-Username' => $apiuser);
-    $headers->header('Api-Token'    => $apitoken);
+    $headers->header('Api-Username' => $user);
+    $headers->header('Api-Token'    => $token);
 }
 
 method action ($method, %args) {
@@ -101,8 +101,8 @@ method resource (@segments) {
         timeout    => $self->timeout,
         user_agent => $self->user_agent,
         identifier => $self->identifier,
-        apiuser    => $self->apiuser,
-        apitoken   => $self->apitoken,
+        token      => $self->token,
+        user       => $self->user,
         version    => $self->version,
     );
 
@@ -135,15 +135,15 @@ API::Name - Perl 5 API wrapper for Name
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
     use API::Name;
 
     my $name = API::Name->new(
-        apiuser    => 'APIUSER',
-        apitoken   => 'APITOKEN',
+        user       => 'USER',
+        token      => 'TOKEN',
         identifier => 'APPLICATION NAME',
     );
 
@@ -316,19 +316,19 @@ represent and process the HTTP transaction.
 
 =head1 ATTRIBUTES
 
-=head2 apitoken
+=head2 token
 
-    $name->apitoken;
-    $name->apitoken('APITOKEN');
+    $name->token;
+    $name->token('TOKEN');
 
-The apitoken parameter should be set to the API token assigned to the account holder.
+The token parameter should be set to the API token assigned to the account holder.
 
-=head2 apiuser
+=head2 user
 
-    $name->apiuser;
-    $name->apiuser('APIUSER');
+    $name->user;
+    $name->user('USER');
 
-The apiuser parameter should be set to the API apiuser assgined to the account holder.
+The user parameter should be set to the API user assgined to the account holder.
 
 =head2 identifier
 
@@ -392,9 +392,9 @@ used in all HTTP requests. This attribute expects a L<Mojo::UserAgent> object.
 
     # e.g.
 
-    $name->action('head', %args);   # HEAD request
-    $name->action('optons', %args); # OPTIONS request
-    $name->action('patch', %args);  # PATCH request
+    $name->action('head', %args);    # HEAD request
+    $name->action('options', %args); # OPTIONS request
+    $name->action('patch', %args);   # PATCH request
 
 The action method issues a request to the API resource represented by the
 object. The first parameter will be used as the HTTP request method. The
